#include "stdafx.h"
#include "gl_light.h"
#include "clf_random.h"
#include "clf_primitives.h"
#include "clf_geometry.h"
#include "clf_camera.h"

extern HWND  hWnd;						// Window Handle
extern bool keyDown[256];			// holds true / false for each key

cCamera g_cam;
clf_stage g_stage;
float anglex=0.f;
float angley=0.f;
float anglez=0.f;

void game_init()
{
	g_cam.setup(clf_vector3D(0,0,25),       // position viewer
							clf_vector3D(0,0,0),        // setup the point of interest (where we are looking at)
							clf_vector3D(0,1,0));       // which way is up

	glEnable (GL_DEPTH_TEST);        // enable depth test
	glEnable(GL_COLOR_MATERIAL);     // use color for drawing the object
	glEnable (GL_LIGHTING);					 // enable lighting
	glEnable (GL_LIGHT0);						 // and turn on light 0
	static GLfloat light_ambient[] = { 0.1f, 0.1f, 0.1f, 1.f };        // the colour and intesity of the ambient light
	static GLfloat light_diffuse[] = { 0.3f, 0.3f, 0.3f, 1.f };        // the difuse property of the surface
	static GLfloat light_specular[] = { 0.95f, 0.95f, 0.95f, 1.f };    // the specular property
	// pass them to OpenGL
	glLightfv (GL_LIGHT0, GL_AMBIENT, light_ambient);
	glLightfv (GL_LIGHT0, GL_DIFFUSE, light_diffuse);
	glLightfv (GL_LIGHT0, GL_SPECULAR, light_specular);
}

void resize_window (int width, int height)			// reshape the window when it's moved or resized
{
	g_stage.resize(0,0,width, height);

	glMatrixMode (GL_PROJECTION);									// select the projection matrix
	glLoadIdentity ();														// reset the projection matrix

	// viewport and perspective
	g_stage.prepare(); 
}

void game_terminate()
{
}

void frame_move(float fElapsed)
{
	if (keyDown[VK_ESCAPE]) 
		DestroyWindow(hWnd);

	anglex += 22.5f * fElapsed;
	angley += 22.5f * fElapsed;
	anglez += 22.5f * fElapsed;
}

void frame_render()
{
	// clear the screen
	glClearColor (0.f, 0.f, 0.f, 1.f);				// background colour
	glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);	// clear screen and depth buffer

	glMatrixMode (GL_MODELVIEW);								// select the modelview matrix
	glLoadIdentity ();													// reset

	// position the viewer
	g_cam.apply();

	// position the light
	static GLfloat light_position[] = { 80.f, 0.f, 0.f, 0.f };				 // the position of the light
	glLightfv (GL_LIGHT0, GL_POSITION, light_position);

	// rotate the object
	glRotatef(anglex, 1,0,0);
	glRotatef(angley, 0,1,0);
	glRotatef(anglez, 0,0,1);

	// set the colour
	glColor3f(0.1f, 0.1f, 1.f);

	// and draw the cube or the sphere
	drawBox(4, 4, 4);
	//drawSphere(3);
}
